@@ -85,7 +85,7 @@ class PodcastEpisodes:
         (most recent first).
         """
         episodes = self._episodes.values()
-        return sorted(episodes, key=lambda e: e.created_at, reverse=True)
+        return sorted(episodes, key=lambda e: e.episode_number, reverse=True)
 
     def to_json(self) -> dict:
         """Provide json data for all of the podcast episodes."""
@@ -114,6 +114,7 @@ class Podcast:
         feed: str,
         episode_data: dict,
         tags: List[str] = None,
+        reverse_episode_order: bool = False,
         created_at: Optional[datetime] = None,
         updated_at: Optional[datetime] = None,
     ) -> None:
@@ -122,6 +123,7 @@ class Podcast:
         self.title = title
         self.feed = feed
         self.tags = tags
+        self.reverse_episode_order = reverse_episode_order
         self.created_at = created_at or datetime.utcnow()
         self.updated_at = updated_at or datetime.utcnow()
 
@@ -188,16 +190,17 @@ class Podcast:
         resp = requests.get(self.feed, timeout=PODCAST_REFRESH_TIMEOUT)
         content = BytesIO(resp.content)
         feed_data = feedparser.parse(content)
+        entries = feed_data.entries
+        if self.reverse_episode_order:
+            entries.reverse()
 
-        number_of_entries = len(feed_data.entries)
-        for entry_number, raw_data in enumerate(feed_data.entries):
+        number_of_entries = len(entries)
+        for entry_number, raw_data in enumerate(entries):
             episode_data = self._parse_episode_feed_data(**raw_data)
 
             # If no episode number can be parsed from the RSS feed data, guess based
             # on position in the loop.
-            episode_data["episode_number"] = episode_data.get("episode_number") or (
-                number_of_entries - entry_number
-            )
+            episode_data["episode_number"] = number_of_entries - entry_number
 
             episode = self.episodes.get(episode_data["id"], allow_empty=True)
             if episode:
@@ -207,11 +210,14 @@ class Podcast:
 
             episodes_seen.append(episode_data["id"])
 
-        # clean up old episodes no longer present in the feed
+        # Clean up old episodes no longer present in the feed
         for episode in self.episodes.list():
             if episode.id not in episodes_seen:
                 self.episodes.delete(episode.id)
 
+        # Register that the podcast's data has been updated.
+        self.updated_at = datetime.utcnow()
+
     def tag(self, tag_name: str) -> None:
         """Apply a tag to the podcast."""
         self.tags.append(tag_name)
@@ -231,6 +237,7 @@ class Podcast:
             "title": self.title,
             "feed": self.feed,
             "tags": self.tags,
+            "reverse_episode_order": self.reverse_episode_order,
             "created_at": created_at,
             "updated_at": updated_at,
             "episode_data": self.episodes.to_json(),
@@ -244,7 +251,6 @@ class Podcast:
         links: list,
         published_parsed: tuple,
         subtitle: Optional[str] = None,
-        itunes_episode: Optional[str] = None,
         updated_parsed: Optional[tuple] = None,
         **kwargs,
     ) -> dict:
@@ -267,11 +273,6 @@ class Podcast:
         url = self._get_download_url(links)
         published_parsed = datetime(*published_parsed[:6])
 
-        if itunes_episode:
-            episode_number = int(itunes_episode)
-        else:
-            episode_number = None
-
         if subtitle:
             short_description = self._strip_html_and_non_ascii_characters(subtitle)
         else:
@@ -288,7 +289,6 @@ class Podcast:
             "long_description": long_description,
             "url": url,
             "created_at": published_parsed,
-            "episode_number": episode_number,
             "short_description": short_description,
             "updated_at": updated_parsed,
         }
